@@ -6,5 +6,6 @@ import MyInteger (MyInteger (MyInteger), toMyInteger)
 
 main :: IO ()
 main = do
-  let (MyInteger i) = (id . toMyInteger) (41 :: Integer)
+  let (MyInteger i) = toMyInteger (41 :: Integer)
   print i
+
